aboutsummaryrefslogtreecommitdiff
path: root/Ryujinx.Graphics.Shader/SupportBuffer.cs
diff options
context:
space:
mode:
Diffstat (limited to 'Ryujinx.Graphics.Shader/SupportBuffer.cs')
-rw-r--r--Ryujinx.Graphics.Shader/SupportBuffer.cs8
1 files changed, 4 insertions, 4 deletions
diff --git a/Ryujinx.Graphics.Shader/SupportBuffer.cs b/Ryujinx.Graphics.Shader/SupportBuffer.cs
index 28a48c2a..5fe99327 100644
--- a/Ryujinx.Graphics.Shader/SupportBuffer.cs
+++ b/Ryujinx.Graphics.Shader/SupportBuffer.cs
@@ -24,8 +24,8 @@ namespace Ryujinx.Graphics.Shader
public static int ComputeRenderScaleOffset;
public const int FragmentIsBgraCount = 8;
- // One for the render target, 32 for the textures, and 8 for the images.
- public const int RenderScaleMaxCount = 1 + 32 + 8;
+ // One for the render target, 64 for the textures, and 8 for the images.
+ public const int RenderScaleMaxCount = 1 + 64 + 8;
private static int OffsetOf<T>(ref SupportBuffer storage, ref T target)
{
@@ -52,7 +52,7 @@ namespace Ryujinx.Graphics.Shader
public Vector4<float> ViewportInverse;
public Vector4<int> FragmentRenderScaleCount;
- // Render scale max count: 1 + 32 + 8. First scale is fragment output scale, others are textures/image inputs.
- public Array41<Vector4<float>> RenderScale;
+ // Render scale max count: 1 + 64 + 8. First scale is fragment output scale, others are textures/image inputs.
+ public Array73<Vector4<float>> RenderScale;
}
} \ No newline at end of file